const express = require("express");
const router = express.Router();

const { EdcClient } = require("../client");

const ERROR_MSG =
  "Failed to fetch Connector Info. Please check if the connector is running";

module.exports = (keycloak) => {
  router.get("/edc-config", keycloak.protect(), async (req, res) => {
    try {
      res.send({
        providerAddress: process.env.EDC_PROVIDER_ADDRESS,
      });
    } catch (error) {
      console.error(error);
      res.status(400).send(ERROR_MSG);
    }
  });

  router.get("/dataplanes", keycloak.protect(), async (req, res) => {
    try {
      const response = await EdcClient.get("/v2/dataplanes");
      res.send(response.data);
    } catch (error) {
      console.error(error);
      res.status(400).send(ERROR_MSG);
    }
  });

  router.get("/register-dataplane", async (req, res) => {
    try {
      const body = require("./payloads/register-data-plane-consumer.json");
      const response = await EdcClient.post("/v2/dataplanes", body);
      res.send(response.data);
    } catch (error) {
      console.error(error);
      res.status(400).send(ERROR_MSG);
    }
  });

  router.get("/fetchCatalog", async (req, res) => {
    try {
      const { providerAddress } = req.query;

      const body = require("./payloads/fetch-catalog.json");
      body.counterPartyAddress = providerAddress;

      const response = await EdcClient.post("/v2/catalog/request", body);
      res.send(response.data);
    } catch (error) {
      console.error(error);
      res.status(400).send(ERROR_MSG);
    }
  });

  router.post("/negotiate", keycloak.protect(), async (req, res) => {
    try {
      const { contractId, assetId } = req.body;

      let ngPayload = require("./payloads/negotiate-contract.json");
      ngPayload.policy["@id"] = contractId;
      ngPayload.policy["target"] = assetId;

      const response = await EdcClient.post(
        "/v2/contractnegotiations",
        ngPayload
      );
      res.send(response.data);
    } catch (error) {
      console.error(error);
      res.status(400).send(ERROR_MSG);
    }
  });

  router.get(
    "/negotiate/:negotiationId",
    keycloak.protect(),
    async (req, res) => {
      try {
        const { negotiationId } = req.params;
        const response = await EdcClient.get(
          `/v2/contractnegotiations/${negotiationId}`
        );

        res.send(response.data);
      } catch (error) {
        console.error(error);
        res.status(400).send(ERROR_MSG);
      }
    }
  );

  router.post("/transferdata", keycloak.protect(), async (req, res) => {
    try {
      const { contractId, assetId } = req.body;

      let transferPayload = require("./payloads/start-transfer.json");
      transferPayload.contractId = contractId;
      transferPayload.assetId = assetId;

      const response = await EdcClient.post(
        `/v2/transferprocesses`,
        transferPayload
      );
      res.send(response.data);
    } catch (error) {
      console.error(error);
      res.status(400).send(ERROR_MSG);
    }
  });

  return router;
};
